@@ -196,7 +196,7 @@ class TestFormHelpers(TestCase):
 
         # Ensure those errors were rendered
         self.assertTrue('<li>Passwords dont match</li>' in html)
-        self.assertTrue('This field is required.' in html)
+        self.assertTrue(unicode(_('This field is required.')) in html)
         self.assertTrue('error' in html)
 
         # Now we render without errors
@@ -206,7 +206,7 @@ class TestFormHelpers(TestCase):
 
         # Ensure errors were not rendered
         self.assertFalse('<li>Passwords dont match</li>' in html)
-        self.assertFalse('This field is required.' in html)
+        self.assertFalse(unicode(_('This field is required.')) in html)
         self.assertFalse('error' in html)
 
     def test_crispy_tag_without_helper(self):
@@ -316,6 +316,29 @@ class TestFormLayout(TestCase):
         settings.CRISPY_FAIL_SILENTLY = False
         self.assertRaises(Exception, lambda:template.render(c))
         del settings.CRISPY_FAIL_SILENTLY
+        
+    def test_layout_uses_instance_for_missing_fields(self):
+        class FormWithMeta(TestForm):
+            class Meta:
+                fields = ('email', 'first_name', 'last_name')
+        form = FormWithMeta()
+        # We remove email field on the go
+        del form.fields['email']
+                
+        form_helper = FormHelper()
+        form_helper.add_layout(
+            Layout(
+                'first_name',
+            )
+        )
+
+        template = get_template_from_string(u"""
+            {% load crispy_forms_tags %}
+            {% crispy form form_helper %}
+        """)        
+        c = Context({'form': form, 'form_helper': form_helper})
+        html = template.render(c)
+        self.assertFalse('email' in html)
 
     def test_layout_unresolved_field(self):
         form = TestForm()
@@ -419,13 +442,14 @@ class TestFormLayout(TestCase):
                     css_class = "columns",
                 ),
                 ButtonHolder(
-                    Submit('Save the world', 'Save', css_class='button white'),
+                    Submit('Save the world', 'Save', css_class='button white', data_id='test', data_name='test'),
                 ),
                 Div(
                     'password1', 
                     'password2',
                     css_id="custom-div",
                     css_class="customdivs",
+                    test_markup="123"
                 )
             )
         )
@@ -444,9 +468,14 @@ class TestFormLayout(TestCase):
         self.assertTrue('class="formColumn columns"' in html)
         self.assertTrue('class="buttonHolder">' in html)
         self.assertTrue('input type="submit"' in html)
+        self.assertTrue('button white' in html)
+        self.assertTrue('data-id="test"' in html)
+        self.assertTrue('data-name="test"' in html)
         self.assertTrue('name="save-the-world"' in html)
         self.assertTrue('id="custom-div"' in html)
         self.assertTrue('class="customdivs"' in html)
+        self.assertTrue('test-markup="123"' in html)
+
 
     def test_layout_within_layout(self):
         form_helper = FormHelper()
